# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'
%define _with_repolib 1

%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define repodir %{_javadir}/repository.jboss.com/hibernate-commons-annotations/%{version}.%{reltag}-brew
%define repodirlib %{repodir}/lib
%define repodirres %{repodir}/resources
%define repodirsrc %{repodir}/src

%define section free

%define reltag GA
%define hname hibernate-commons-annotations
%define namedversion %{version}.%{reltag}

Summary:        Relational persistence and query service
Name:           hibernate3-commons-annotations
Version:        3.1.0
Release:        1.8%{?dist}
Epoch:          0
License:        LGPL
URL:            http://annotations.hibernate.org/
Group:          Database
Source0:        hibernate-commons-annotations-3.1.0-src.tar.gz
# svn export https://svn.jboss.org/repos/hibernate/commons-annotations/tags/3.1.0.GA/ hibernate-commons-annotations
# tar czf hibernate-commons-annotations-3.1.0-src.tar.gz hibernate-commons-annotations
Source1:	%{hname}-jdstyle.css
Source2:	%{hname}-component-info.xml

Patch0:         %{hname}-common-build_xml.patch
Patch1:         %{hname}-ivy.xml.patch

BuildRequires:  jpackage-utils >= 0:1.7.3
BuildRequires:  java-devel >= 1.5.0
BuildRequires:  ant >= 0:1.7.1
BuildRequires:  ant-junit
BuildRequires:  ant-contrib
BuildRequires:  ivy
BuildRequires:  maven2 >= 0:2.0.8
BuildRequires:  maven-ant-tasks
BuildRequires:  javassist >= 3.9.0
BuildRequires:  junit >= 3.8.2
BuildRequires:  log4j >= 1.2.14
BuildRequires:  hibernate3 >= 0:3.3.2
BuildRequires:  hibernate3-ejb-persistence-3.0-api >= 1:1.0.2
BuildRequires:  hsqldb
BuildRequires:  slf4j >= 0:1.5.6
BuildRequires:  maven-deploy-plugin

Requires:       java >= 0:1.5
Requires:       hibernate3 >= 0:3.3.2
Requires:       hibernate3-ejb-persistence-3.0-api >= 1:1.0.2
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
Hibernate Commons Annotations is a utility project used by annotations based
Hibernate sub-projects.
It's first scope is to support Java Generics type discovery.
It's second scope is to support Java Annotations overriding through XML files
(mainly but not conceptually limited to)

%if %{with_repolib}
%package	 repolib
Summary:	 Artifacts to be uploaded to a repository library
Group:	Development/Libraries/Java

%description	 repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio
%endif

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%prep
%setup -q -n %{hname}
# remove all binary libs
for j in $(find . -name "*.jar"); do
	mv $j $j.no
done
mkdir -p doc/api
cp %{SOURCE1} doc/api/jdstyle.css

%patch0 -b .sav
%patch1 -b .sav

cp %{SOURCE2} .
sed -i 's/@VERSION@/%{version}.%{reltag}-brew/g' %{hname}-component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{hname}-component-info.xml

%build
export JAVA_HOME=/usr/lib/jvm/java-1.6.0

build-jar-repository -s -p ivy \
	ivy \
	maven-ant-tasks

build-jar-repository -s -p lib/build \
ant-contrib \
ant/ant-junit \
junit

mkdir -p build/lib/core
build-jar-repository -s -p build/lib/core \
slf4j/api

mkdir -p build/lib/test
build-jar-repository -s -p build/lib/test \
hibernate-core \
hibernate3-ejb-persistence-3.0-api \
junit \
javassist \
slf4j/log4j12 \
log4j

mkdir jdbc
build-jar-repository -s -p jdbc hsqldb

ant \
	-Doffline.repository.jboss.org=$PWD/build \
	jar javadoc junit junitinstrument deploy

## For junitinstrument task, there are expected failures in:
## org.hibernate.test.reflection.java.JavaXClassTest
## org.hibernate.test.reflection.java.JavaXPropertyTest

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p target/%{hname}/%{hname}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|%{name}|%{hname}|g"`; done)
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

## javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
#cp -pr target/%{hname}/doc/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
#(cd $RPM_BUILD_ROOT%{_javadocdir} && for doc in *-%{version}; do ln -sf ${doc} `echo $doc| sed "s|%{name}|%{hname}|g"`; done)
#(cd $RPM_BUILD_ROOT%{_javadocdir} && for doc in *-%{version}; do ln -sf ${doc} `echo $doc| sed "s|-%{version}||g"`; done)
cp -pr target/%{hname}/doc/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

# manual
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -p lgpl.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}

#pom
%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%add_to_maven_depmap org.hibernate %{hname} %{namedversion} JPP %{name}
%{__install} -p -m 644 build/pom.xml %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom


%if %{with_repolib}
	install -d -m 755 $RPM_BUILD_ROOT%{repodir}
	%{_bindir}/mvn-jpp deploy:deploy-file \
	-DgroupId=org.hibernate \
	-DartifactId=%{hname} \
	-Dversion=%{namedversion} \
	-Dpackaging=jar \
	-Dfile=%{buildroot}%{_javadir}/%{hname}.jar \
	-DpomFile=%{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom \
	-Durl=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/ \
	-DrepositoryId=jboss-releases
    %{_bindir}/mvn-jpp deploy:deploy-file \
	-DgroupId=org.hibernate \
	-DartifactId=%{hname} \
	-Dversion=%{namedversion} \
	-Dpackaging=java-source \
    -DgeneratePom=false \
	-Dfile=build/src.jar \
	-Durl=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/ \
	-DrepositoryId=jboss-releases
	install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
	install -m 755 %{hname}-component-info.xml $RPM_BUILD_ROOT%{repodir}/component-info.xml
	install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{PATCH1} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
	cp $RPM_BUILD_ROOT%{_javadir}/%{hname}.jar $RPM_BUILD_ROOT%{repodirlib}
	cp -p build/src.jar $RPM_BUILD_ROOT%{repodirlib}/%{hname}-sources.jar
	cp -p %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom $RPM_BUILD_ROOT%{repodirlib}/hibernate-commons-annotations.pom
%endif
%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%postun javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}
fi

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}/lgpl.txt
%{_javadir}*/*.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%ghost %doc %{_javadocdir}/%{name}

%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Wed Jan 05 2011 Hui Wwang <huwang@redhat.com> - 0:3.1.0-1.8
- Fix %%files for signed jars
- Add deploy command in repolib and add BR maven-deploy-plugin

* Sat Aug 07 2010 Strong Liu <stliu@redhat.com> - 0:3.1.0-1.7
- Rebuild

* Wed Apr 21 2010 Hui Wang <huwang@redhat.com> - 0:3.1.0-1.6
- Change export JAVA_HOME=/usr/lib/jvm/java-1.5.0 to export JAVA_HOME=/usr/lib/jvm/java-1.6.0
- Rebuild to generate signed jar

* Mon Apr 19 2010 Luiz Barreiros <gbarreir@redhat.com> - 0:3.1.0-1.5
- Rebuild

* Sat Jan 30 2010 Strong Liu <stliu@redhat.com> - 0:3.1.0-1.4
- Add pom to repolib

* Thu Jan 21 2010 Strong Liu <stliu@redhat.com> - 0:3.1.0-1.3
- Fix hibernate3-ejb-persistence-3.0-api version to 1.0.2

* Mon Jul 20 2009 Strong Liu <stliu@redhat.com> - 0:3.1.0-1.2
- Change the source jars name to *-sources.jar
- Update copyrights to 2009
* Sat Jul 18 2009 Gail Badner <gbadner@redhat.com> - 0:3.1.0-1.1
- First release for RHEL-4-EP-5
